#!/bin/bash
#************************ Warning **********************************
#*                                                                 *
#* This configuration is property of OPEN SOURCE CONSULTING, INC.  *
#* Don't distribute this to other project.                         *
#*                                                                 *
#* Contact jchoi@osci.kr(http://www.osci.kr)                       *
#*******************************************************************

#####################################
# This is tomcat env.sh for iosp by Open Source Consulting, Inc
#####################################

export DATE=`date +%Y%m%d_%H%M%S`

#####################################
## Set Tomcat base env
#####################################
export JAVA_HOME=/usr/local/jdk1.8
export SERVER_NAME=ums-api-11
export CATALINA_HOME=/usr/local/tomcat
export CATALINA_BASE=/cont02/servers/$SERVER_NAME
export LOG_DIR=${CATALINA_BASE}/logs
export GC_LOG_DIR=${LOG_DIR}/

export PORT_OFFSET=10100
export COMP_USER=ebest

#####################################
##### Tomcat Cluster #####
#####################################
#export BIND_ADDR=192.168.0.143
#export MULTICAST_ADDR=230.111.222.143
#export CLUSTER_PORT=$(expr 7600 + $PORT_OFFSET)

#####################################
## Set Port Configuration
#####################################
#  Default Ports are as below       
#  HTTP_PORT	    : 8080	    
#  SSL_PORT 	    : 8443	    
#  SHUTDOWN_PORT    : 8005	    
#####################################

#export CUSTOM_HTTP_PORT=8080
#export CUSTOM_AJP_PORT=8009
#export CUSTOM_SSL_PORT=
#export CUSTOM_SHUTDOWN_PORT=


if [ "x$CUSTOM_HTTP_PORT" = "x" ]; then
    export HTTP_PORT=$(expr 8080 + $PORT_OFFSET)
else
    export HTTP_PORT=$CUSTOM_HTTP_PORT
fi

if [ "x$CUSTOM_AJP_PORT" = "x" ]; then
    export AJP_PORT=$(expr 8009 + $PORT_OFFSET)
else
    export AJP_PORT=$CUSTOM_AJP_PORT
fi

if [ "x$CUSTOM_SSL_PORT" = "x" ]; then
    export SSL_PORT=$(expr 8443 + $PORT_OFFSET)
else
    export SSL_PORT=$CUSTOM_SSL_PORT
fi

if [ "x$CUSTOM_SHUTDOWN_PORT" = "x" ]; then
    export SHUTDOWN_PORT=$(expr 8005 + $PORT_OFFSET)
else
    export SHUTDOWN_PORT=$CUSTOM_SHUTDOWN_PORT
fi

#####################################
## JVM Parameter Configuration
#####################################

if [ "x$JAVA_OPTS" = "x" ]; then
   JAVA_OPTS="-server"
   JAVA_OPTS="$JAVA_OPTS -Dserver=$SERVER_NAME"
   JAVA_OPTS="$JAVA_OPTS -Dhttp.port=$HTTP_PORT"
   JAVA_OPTS="$JAVA_OPTS -Dajp.port=$AJP_PORT"
   JAVA_OPTS="$JAVA_OPTS -Dssl.port=$SSL_PORT"
   JAVA_OPTS="$JAVA_OPTS -Dshutdown.port=$SHUTDOWN_PORT"
   JAVA_OPTS="$JAVA_OPTS -Djava.library.path=${CATALINA_HOME}/lib/"

#####################################
## Set Port Configuration
#####################################

    JAVA_OPTS="$JAVA_OPTS -noverify"
    JAVA_OPTS="$JAVA_OPTS -Xms2048m"
    JAVA_OPTS="$JAVA_OPTS -Xmx2048m"
    JAVA_OPTS="$JAVA_OPTS -XX:MetaspaceSize=256m"
    JAVA_OPTS="$JAVA_OPTS -XX:MaxMetaspaceSize=512m"
#   JAVA_OPTS="$JAVA_OPTS -Xss128k"

    JAVA_OPTS="$JAVA_OPTS -verbose:gc"
    JAVA_OPTS="$JAVA_OPTS -Xloggc:${GC_LOG_DIR}/gc.log"
    JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCDetails"
    JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCTimeStamps"
#   JAVA_OPTS="$JAVA_OPTS -XX:+PrintHeapAtGC"
    JAVA_OPTS="$JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError"
    JAVA_OPTS="$JAVA_OPTS -XX:HeapDumpPath=${LOG_DIR}/${SERVER_NAME}.$DATE.hprof"
    JAVA_OPTS="$JAVA_OPTS -XX:+UseParallelGC"
    JAVA_OPTS="$JAVA_OPTS -XX:+ExplicitGCInvokesConcurrent"
    JAVA_OPTS="$JAVA_OPTS -XX:+DisableExplicitGC"

#   JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote"
#   JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.port=${JMX_PORT}"
#   JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.ssl=false"
#   JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.authenticate=false"
    
    JAVA_OPTS="$JAVA_OPTS -Dsun.lang.ClassLoader.allowArraySyntax=true "
    JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.client.gcInterval=3600000"
    JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.server.gcInterval=3600000"

#    JAVA_OPTS="$JAVA_OPTS -Dorg.apache.catalina.STRICT_SERVLET_COMPLIANCE=true"
    JAVA_OPTS="$JAVA_OPTS -Dorg.apache.catalina.STRICT_SERVLET_COMPLIANCE=false"
    JAVA_OPTS="$JAVA_OPTS -Dbind.addr=$BIND_ADDR"
    JAVA_OPTS="$JAVA_OPTS -Dmulticast.addr=$MULTICAST_ADDR"
    JAVA_OPTS="$JAVA_OPTS -Dcluster.recv.port=$CLUSTER_PORT"

    JAVA_OPTS="$JAVA_OPTS -Djava.awt.headless=true"
    JAVA_OPTS="$JAVA_OPTS -Djava.net.preferIPv4Stack=true"
    JAVA_OPTS="$JAVA_OPTS -Djava.security.egd=file:/dev/./urandom"
#    JAVA_OPTS="$JAVA_OPTS -Djava.util.logging.manager=org.apache.juli.ClassLoaderLogManager"
#    JAVA_OPTS="$JAVA_OPTS -Djava.awt.headless=true"

   JAVA_OPTS="$JAVA_OPTS -javaagent:/opt/apm/scouter/agent.java/scouter.agent.jar"
   JAVA_OPTS="$JAVA_OPTS -Dscouter.config=/opt/apm/scouter/agent.java/conf/ums-api.conf"
   LOCAL_IP_END=$(curl http://169.254.169.254/latest/meta-data/local-ipv4 2> /dev/null | awk -F. '{print $4}');

sudo bash <<EOF
     sed -i -e '/obj_name/d' /opt/apm/scouter/agent.java/conf/ums-api.conf
     echo "obj_name=ums-api-${LOCAL_IP_END}" >> /opt/apm/scouter/agent.java/conf/ums-api.conf
EOF

fi

#####################################
## Athena Dolly Clustering
#####################################
#export JAVA_OPTS="$JAVA_OPTS -Ddolly.properties=/opt/dolly-agent-new/dolly.properties"
#export JAVA_OPTS="$JAVA_OPTS -javaagent:/opt/dolly-agent-new/lib/core-1.0.0-SNAPSHOT.jar"

#####################################
## Set Scouter Tomcat Agent
#####################################
#export JAVA_OPTS="$JAVA_OPTS -javaagent:/usr/local/scouter/agent.java/scouter.agent.jar"
#export JAVA_OPTS="$JAVA_OPTS -Dscouter.config=/usr/local/scouter/agent.java/conf/${SERVER_NAME}.conf"

export JAVA_OPTS

# ThinkTree Eddie: Customize
echo "================================================"
echo "SERVICE_NAME      = e-BEST WEB (Development Server)"
echo "SERVER_NAME       = $SERVER_NAME"
echo "JAVA_HOME         = $JAVA_HOME"
echo "CATALINA_HOME     = $CATALINA_HOME"
echo "SERVER_HOME       = $CATALINA_BASE"
echo "HTTP_PORT         = $HTTP_PORT"
echo "SSL_PORT          = $SSL_PORT"
echo "AJP_PORT          = $AJP_PORT"
echo "SHUTDOWN_PORT     = $SHUTDOWN_PORT"
echo "CATALINA_HOME     = $CATALINA_HOME"
echo "CATALINA_BASE	= $CATALINA_BASE"
echo "================================================"
